==> maxcpu_0.1.5-6.tar.gz: maxcpu-0.1.5/usr/lib/hildon-desktop/maxcpu.py <==
# maxCPU
# Version 0.1.5 English version
# Home Desktop Widget for fast change of CPU's clock
# by Marco (m750 at www.maemomeego.net)

import hildondesktop
import os
import sys
import gtk
import gobject


# definisco Label e bottoni a livello globale (inserendoli qui)

testo = gtk.Label(" No Titan ")
testo.set_width_chars(8)
button_1 = gtk.Button("+")
button_2 = gtk.Button("-")

# variabile globale
# la dichiarazione va ripetuta nei def
global risultato


def getmaxfreq():
        try:
             maxcpu = os.popen('echo $((`cat /sys/devices/system/cpu/cpu0/cpufreq/scaling_max_freq`/1000))').read()
        except:
             print (maxcpu)
        else:
             maxcpu = maxcpu.strip()
             #print maxcpu, "MHz"
             return(maxcpu)


def getminfreq():
        mincpu = os.popen('echo $((`cat /sys/devices/system/cpu/cpu0/cpufreq/scaling_min_freq`/1000))').read()
        mincpu = mincpu.strip()
        return(mincpu)


# aggiorno la label con la frequenza massima e cambio il colore
def scrivi_frequenza():
    mhz = int(getmaxfreq())
    scrivi = "<span foreground='Red'> No Titan </span>"
    if mhz > 700:
           scrivi = "<span foreground='Red'> " + str(mhz) + " MHz </span>"
    else:
          scrivi = "<span foreground='White'> " + str(mhz) + " MHz </span>"
    testo.set_markup( scrivi )


def conferma():
    dialog = gtk.Dialog()
    dialog.set_title('Confirm over 805 Mhz')

    dialog.add_button(gtk.STOCK_YES, gtk.RESPONSE_YES)
    dialog.add_button(gtk.STOCK_NO, gtk.RESPONSE_NO)

    #dialog.show_all()
    global risultato
    risultato = dialog.run()
    dialog.destroy()


def limite_min_max():
    dialog = gtk.Dialog()
    dialog.set_title('maxCPU: CPU limit')
    dialog.add_button(gtk.STOCK_OK, gtk.RESPONSE_OK)
    ris = dialog.run()
    dialog.destroy()
  

def aumenta(data=None):
    print "Aumento?"
    mhz = int(getmaxfreq())
    fmin = int(getminfreq())


    if mhz == 250:
        frequenza_nuova = 500
    elif mhz == 500:
        frequenza_nuova = 550
    elif mhz == 550:
        frequenza_nuova = 600
    elif mhz == 600:
        frequenza_nuova = 700
    elif mhz == 700:
        frequenza_nuova = 750
    elif mhz == 750:
        frequenza_nuova = 805
    elif mhz == 805:
        frequenza_nuova = 850
    elif mhz == 850:
        frequenza_nuova = 900
    elif mhz == 900:
        frequenza_nuova = 950
    elif mhz == 950:
        frequenza_nuova = 1000
    elif mhz == 1000:
        frequenza_nuova = 1100
    elif mhz == 1100:
        frequenza_nuova = 1150
    else:
        frequenza_nuova = mhz
        limite_min_max()

    if frequenza_nuova > mhz and frequenza_nuova > 805:
        conferma()
        global risultato 
        if risultato == gtk.RESPONSE_YES:
            os.popen("/usr/sbin/kernel-config limits " + str(fmin) + " " + str(frequenza_nuova))
            print "kernel-config limits " + str(fmin) + " " + str(frequenza_nuova)

    elif frequenza_nuova > mhz:
        print "kernel-config limits " + str(fmin) + " " + str(frequenza_nuova)
        os.popen("/usr/sbin/kernel-config limits " + str(fmin) + " " + str(frequenza_nuova))
    else:
        print "annulla aumenta"

    scrivi_frequenza()


def diminuisci(data=None):
    print "Diminuisco"
    mhz = int(getmaxfreq())
    fmin = int(getminfreq())
    print fmin, " ", mhz

    if mhz == 500:
        frequenza_nuova = 250
    elif mhz == 550:
        frequenza_nuova = 500
    elif mhz == 600:
        frequenza_nuova = 550
    elif mhz == 700:
        frequenza_nuova = 600
    elif mhz == 750:
        frequenza_nuova = 700
    elif mhz == 805:
        frequenza_nuova = 750
    elif mhz == 850:
        frequenza_nuova = 805
    elif mhz == 900:
        frequenza_nuova = 850
    elif mhz == 950:
        frequenza_nuova = 900
    elif mhz == 1000:
        frequenza_nuova = 950
    elif mhz == 1100:
        frequenza_nuova = 1000
    elif mhz == 1150:
        frequenza_nuova = 1100
    else:
        frequenza_nuova = mhz
        limite_min_max()



    if frequenza_nuova < mhz and frequenza_nuova > fmin:

        print "kernel-config limits " + str(fmin) + " " + str(frequenza_nuova)
        os.popen("/usr/sbin/kernel-config limits " + str(fmin) + " " + str(frequenza_nuova))

    scrivi_frequenza()


class maxCPU(hildondesktop.HomePluginItem):


    def __init__(self):
        hildondesktop.HomePluginItem.__init__(self)

        # dichiarazione esitenza finestra dei settaggi
        self.set_settings(True)
        self.connect('show-settings', self.on_settings)

       
        # modifica bottoni
        button_1.set_size_request(50, 46)
        button_2.set_size_request(50, 46)

        # dichiarazione box
        box1 = gtk.HBox()
        box1.set_border_width(2)

        # aggiunta box e resto
        self.add(box1)
        box1.add(button_2)
        box1.add(testo)
        box1.add(button_1)

        # mostra il box
        box1.show_all()

        scrivi_frequenza()

        button_1.connect("clicked", aumenta)
        button_2.connect("clicked", diminuisci)


# dichiarazione finestra settaggi
    def on_settings(self, widget):

        # dialog crea una finestra in basso con dei messaggi
        dialog = gtk.Dialog()
        dialog.set_title('maxCPU')
        dialog.vbox.add(gtk.Label('Version 0.1.5 EN (2010-12-21)'))
        dialog.vbox.add(gtk.Label('Fast change of CPU clock'))
        dialog.vbox.add(gtk.Label('250 Mhz<= Fmin <= newClock <= 1150 Mhz'))
        dialog.vbox.add(gtk.Label('Changes do not remain after reboot'))
        dialog.vbox.add(gtk.Label('Work only with Power Kernel'))
        dialog.vbox.add(gtk.Label('by Marco (m750 at www.maemomeego.net)'))

        dialog.show_all()
        result = dialog.run()
        dialog.destroy()

hd_plugin_type = maxCPU
# per avviarlo da shell
if __name__ == '__main__':
    gobject.type_register(hd_plugin_type)
    obj = gobject.new(hd_plugin_type, plugin_id=hd_plugin_type.__class__.__name__)
    obj.show_all()
    gtk.main()

==> maxcpu_0.1.6-2.tar.gz: maxcpu-0.1.6/usr/lib/hildon-desktop/maxcpu.py <==
# maxCPU
# Version 0.1.6 English version
# Home Desktop Widget for quickly changin of CPU's clock
# by Marco (m750 at www.maemomeego.net)

import hildondesktop
import os
import sys
import gtk
import gobject


# definisco Label e bottoni a livello globale (inserendoli qui)

testo = gtk.Label(" No Titan ")
testo.set_width_chars(8)
button_1 = gtk.Button("+")
button_2 = gtk.Button("-")

# variabile globale
# la dichiarazione va ripetuta nei def
global risultato


def getmaxfreq():
        try:
             maxcpu = os.popen('echo $((`cat /sys/devices/system/cpu/cpu0/cpufreq/scaling_max_freq`/1000))').read()
        except:
             print (maxcpu)
        else:
             maxcpu = maxcpu.strip()
             #print maxcpu, "MHz"
             return(maxcpu)


def getminfreq():
        mincpu = os.popen('echo $((`cat /sys/devices/system/cpu/cpu0/cpufreq/scaling_min_freq`/1000))').read()
        mincpu = mincpu.strip()
        return(mincpu)


# aggiorno la label con la frequenza massima e cambio il colore
def scrivi_frequenza():
    mhz = int(getmaxfreq())
    scrivi = "<span foreground='Red'> No Titan </span>"
    if mhz > 600:
           scrivi = "<span foreground='Red'> " + str(mhz) + " MHz </span>"
    else:
          scrivi = "<span foreground='White'> " + str(mhz) + " MHz </span>"
    testo.set_markup( scrivi )


def conferma(valore):
    dialog = gtk.Dialog()
    testo = 'Confirm for ' + str(valore) + 'Mhz'
    dialog.set_title(testo)

    dialog.add_button(gtk.STOCK_YES, gtk.RESPONSE_YES)
    dialog.add_button(gtk.STOCK_NO, gtk.RESPONSE_NO)

    #dialog.show_all()
    global risultato
    risultato = dialog.run()
    dialog.destroy()


def limite_min_max():
    dialog = gtk.Dialog()
    dialog.set_title('maxCPU: CPU limit')
    dialog.add_button(gtk.STOCK_OK, gtk.RESPONSE_OK)
    ris = dialog.run()
    dialog.destroy()
  

def aumenta(data=None):
    #print "Aumento?"
    mhz = int(getmaxfreq())
    fmin = int(getminfreq())


    if mhz == 250:
        frequenza_nuova = 500
    elif mhz == 500:
        frequenza_nuova = 550
    elif mhz == 550:
        frequenza_nuova = 600
    elif mhz == 600:
        frequenza_nuova = 700
    elif mhz == 700:
        frequenza_nuova = 750
    elif mhz == 750:
        frequenza_nuova = 805
    elif mhz == 805:
        frequenza_nuova = 850
    elif mhz == 850:
        frequenza_nuova = 900
    elif mhz == 900:
        frequenza_nuova = 950
    elif mhz == 950:
        frequenza_nuova = 1000
    elif mhz == 1000:
        frequenza_nuova = 1100
    elif mhz == 1100:
        frequenza_nuova = 1150
    else:
        frequenza_nuova = mhz
        limite_min_max()


    if frequenza_nuova > mhz and (frequenza_nuova == 700 or frequenza_nuova == 850 or frequenza_nuova == 1000) :
        conferma(frequenza_nuova)
        global risultato 
        if risultato == gtk.RESPONSE_YES:
            os.popen("/usr/sbin/kernel-config limits " + str(fmin) + " " + str(frequenza_nuova))
            print "kernel-config limits " + str(fmin) + " " + str(frequenza_nuova)

    elif frequenza_nuova > mhz:
        print "kernel-config limits " + str(fmin) + " " + str(frequenza_nuova)
        os.popen("/usr/sbin/kernel-config limits " + str(fmin) + " " + str(frequenza_nuova))
    else:
        print "annulla aumenta"

    scrivi_frequenza()


def diminuisci(data=None):
    #print "Diminuisco"
    mhz = int(getmaxfreq())
    fmin = int(getminfreq())
    print fmin, " ", mhz

    if mhz == 500:
        frequenza_nuova = 250
    elif mhz == 550:
        frequenza_nuova = 500
    elif mhz == 600:
        frequenza_nuova = 550
    elif mhz == 700:
        frequenza_nuova = 600
    elif mhz == 750:
        frequenza_nuova = 700
    elif mhz == 805:
        frequenza_nuova = 750
    elif mhz == 850:
        frequenza_nuova = 805
    elif mhz == 900:
        frequenza_nuova = 850
    elif mhz == 950:
        frequenza_nuova = 900
    elif mhz == 1000:
        frequenza_nuova = 950
    elif mhz == 1100:
        frequenza_nuova = 1000
    elif mhz == 1150:
        frequenza_nuova = 1100
    else:
        frequenza_nuova = mhz
        limite_min_max()



    if frequenza_nuova < mhz and frequenza_nuova > fmin:

        print "kernel-config limits " + str(fmin) + " " + str(frequenza_nuova)
        os.popen("/usr/sbin/kernel-config limits " + str(fmin) + " " + str(frequenza_nuova))

    scrivi_frequenza()


class maxCPU(hildondesktop.HomePluginItem):


    def __init__(self):
        hildondesktop.HomePluginItem.__init__(self)

        # dichiarazione esitenza finestra dei settaggi
        self.set_settings(True)
        self.connect('show-settings', self.on_settings)

       
        # modifica bottoni
        button_1.set_size_request(50, 46)
        button_2.set_size_request(50, 46)

        # dichiarazione box
        box1 = gtk.HBox()
        box1.set_border_width(2)

        # aggiunta box e resto
        self.add(box1)
        box1.add(button_2)
        box1.add(testo)
        box1.add(button_1)

        # mostra il box
        box1.show_all()

        scrivi_frequenza()

        button_1.connect("clicked", aumenta)
        button_2.connect("clicked", diminuisci)


# dichiarazione finestra settaggi
    def on_settings(self, widget):

        # dialog crea una finestra in basso con dei messaggi
        dialog = gtk.Dialog()
        dialog.set_title('maxCPU')
        dialog.vbox.add(gtk.Label("Quickly changin of CPU's clock"))
        dialog.vbox.add(gtk.Label('Version 0.1.6 EN (2011-01-05)'))
        dialog.vbox.add(gtk.Label('250 Mhz<= Fmin <= newClock <= 1150 Mhz'))
        dialog.vbox.add(gtk.Label('Changes do not remain after reboot'))
        dialog.vbox.add(gtk.Label('Work only with Power Kernel'))
        dialog.vbox.add(gtk.Label('by Marco (m750 at www.maemomeego.net)'))
        dialog.vbox.add(gtk.Label(' '))
        dialog.vbox.add(gtk.Label('WARNING'))
        dialog.vbox.add(gtk.Label('overclocking voids your warranty and may damage your device'))



        dialog.show_all()
        result = dialog.run()
        dialog.destroy()

hd_plugin_type = maxCPU
# per avviarlo da shell
if __name__ == '__main__':
    gobject.type_register(hd_plugin_type)
    obj = gobject.new(hd_plugin_type, plugin_id=hd_plugin_type.__class__.__name__)
    obj.show_all()
    gtk.main()
